@@ -13,7 +13,7 @@ our @EXPORT_OK = qw(datapack_modules);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-29'; # DATE
 our $DIST = 'Module-DataPack'; # DIST
-our $VERSION = '0.220'; # VERSION
+our $VERSION = '0.221'; # VERSION
 
 our %SPEC;
 
@@ -169,7 +169,10 @@ _
     push @res, <<'_';
     $main::_DataPacker::handler = sub {
         my $debug = $ENV{PERL_DATAPACKER_DEBUG};
-        warn "[datapacker] Hook called with arguments: (".join(",", @_).")\n" if $debug;
+        if ($debug) {
+            my @caller0 = caller;
+            warn "[datapacker] Hook called with arguments: (".join(",", @_).") by $caller0[1] line $caller0[2]\n";
+        }
 
         $toc ||= do {
 
@@ -301,7 +304,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.220 of Module::DataPack (from Perl distribution Module-DataPack), released on 2021-08-29.
+This document describes version 0.221 of Module::DataPack (from Perl distribution Module-DataPack), released on 2021-08-29.
 
 =head1 FUNCTIONS
 
